# qbodbc 

Connect to your QuickBooks desktop instance with Python. 

# Connecting 

The application server, and the QuickBooks instance must be on 
the same machine or have QODBC driver and QRemote running 
on the QuickBooks application box. 

The alternative is to run middleware in front of the QuickBooks 
instnace that can deserialize and process incoming qbodbc objects.
